<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>AddExistingDocumentDialog</name>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="14"/>
        <source>Add existing document</source>
        <translation>Добавить существующий докумет</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="51"/>
        <source>Document location:</source>
        <translation>Адрес документа:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="61"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="68"/>
        <source>Document format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="78"/>
        <source>Force read-only mode</source>
        <translation>Открыть только для чтения</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="98"/>
        <source>Custom settings</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="105"/>
        <source>Save file to disk before opening</source>
        <translation>Сохранить локальную копию</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="143"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="153"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>AddNewDocumentDialog</name>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="14"/>
        <source>Add new document</source>
        <translation>Создание документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="50"/>
        <source>Document format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="60"/>
        <source>Document location</source>
        <translation>Адрес документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="70"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="97"/>
        <source>Compress file</source>
        <translation>Применить компрессию gzip</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="137"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="144"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>AnnotationSettingsDialog</name>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="13"/>
        <source>Visualization settings for annotations</source>
        <translation>Настройки визуализации аннотаций</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="26"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="31"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="36"/>
        <source>Amino</source>
        <translation>Амино</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="41"/>
        <source>Highlight</source>
        <translation>Маркировка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="69"/>
        <source>OK</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="82"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="46"/>
        <source>Visual Qualifier</source>
        <translation>Визуальный квалификатор</translation>
    </message>
</context>
<context>
    <name>CopyDocumentDialog</name>
    <message>
        <source>Copy Document</source>
        <translation type="obsolete">Создать копию документа</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="obsolete">Имя файла</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="obsolete">Формат</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="14"/>
        <source>Save a copy</source>
        <translation>Сохранить копию документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="25"/>
        <source>Save to file</source>
        <translation>Сохранить в файл</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="32"/>
        <source>File format</source>
        <translation>Формат файла</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="52"/>
        <source>Add to project</source>
        <translation>Добавить в проект</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="45"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="62"/>
        <source>Compress file</source>
        <translation>Применить компрессию gzip</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="89"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="obsolete">Создать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="96"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>CreateAnnotationWidget</name>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="54"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="82"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="117"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="26"/>
        <source>Create annotations</source>
        <translation>Создание аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="35"/>
        <source>Save annotation(s) to</source>
        <translation>Сохранить результат(ы) в</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="41"/>
        <source>Existing annotation table</source>
        <translation>Существующую таблицу</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="65"/>
        <source>Create new table</source>
        <translation>Новую таблицу</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="92"/>
        <source>Annotation parameters</source>
        <translation>Параметры аннотирования</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="104"/>
        <source>Group name</source>
        <translation>Имя группы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="114"/>
        <source>Predefined group names</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="134"/>
        <source>Annotation name</source>
        <translation>Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="168"/>
        <source>Location</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="148"/>
        <source>Predefined annotation names</source>
        <translation>Стандартные имена аннотаций</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="175"/>
        <source>Annotation location in GenBank format</source>
        <translation>Местоположение аннотации (в формате GenBank)</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="182"/>
        <source>Add/remove complement flag</source>
        <translation>Добавить/снять флаг комплементарности</translation>
    </message>
</context>
<context>
    <name>CreateDocumentFromTextDialog</name>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="14"/>
        <source>Create document</source>
        <translation>Создание документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="22"/>
        <source>Document location:</source>
        <translation>Адрес документа:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="32"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="39"/>
        <source>Document format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="49"/>
        <source>Sequence name</source>
        <translation>Имя последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="56"/>
        <source>Sequence</source>
        <translation>Последовательность</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="87"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="94"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="65"/>
        <source>Save file immediately</source>
        <translation>Записать файл на диск</translation>
    </message>
</context>
<context>
    <name>CreateNewObjectDialog</name>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="39"/>
        <source>Object name</source>
        <translation>Имя объекта:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="49"/>
        <source>Object type</source>
        <translation>Тип объекта:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="59"/>
        <source>Document</source>
        <translation>Документ:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="69"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="113"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="120"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="14"/>
        <source>Create new object</source>
        <translation>Создание объекта</translation>
    </message>
</context>
<context>
    <name>CreateObjectRelationDialog</name>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="13"/>
        <source>Edit object relations</source>
        <translation>Создание связи объекта</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="19"/>
        <source>Associate object with:</source>
        <translation>Связь:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="44"/>
        <source>Ok</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>DownloadRemoteFileDialog</name>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="14"/>
        <source>Fetch data from remote database</source>
        <translation>Получить данные из удаленной базы</translation>
    </message>
    <message>
        <source>Please enter the ID and choose database.</source>
        <translation type="obsolete">Введите идентификатор и выберите базу данных.</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="22"/>
        <source>Resource ID:</source>
        <translation>Идентификатор:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="32"/>
        <source>Database:</source>
        <translation>База данных:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="49"/>
        <source>Save to directory:</source>
        <translation>Сохранить в директорию:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="61"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="90"/>
        <source>Hint</source>
        <translation>Подсказка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="97"/>
        <source>Use database unique identifier.</source>
        <translation>Использовать уникальный идентификатор базы данных.</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="135"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="142"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>EditQualifierDialog</name>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="14"/>
        <source>Edit qualifier</source>
        <translation>Редактировать квалификатор</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="22"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="38"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="77"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="67"/>
        <source>OK</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>EditSequenceDialog</name>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="20"/>
        <source>Annotations region resolving mode</source>
        <translation type="unfinished">Способ обработки аннотаций</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="28"/>
        <source>Resize</source>
        <translation type="unfinished">Изменить размер</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="38"/>
        <source>Remove</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="45"/>
        <source>Split</source>
        <translation type="unfinished">Разбить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="59"/>
        <source>Position to insert</source>
        <translation type="unfinished">Позиция для вставки</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="91"/>
        <source>Save to new file</source>
        <translation type="unfinished">Сохранить в новый файл</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="105"/>
        <source>Document location:</source>
        <translation type="unfinished">Адрес документа:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="115"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="122"/>
        <source>Document format:</source>
        <translation type="unfinished">Формат:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="134"/>
        <source>Merge annotations to this file</source>
        <translation type="unfinished">Сохранить связанные аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="159"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="166"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormatSettingsDialog</name>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="13"/>
        <source>Custom settings</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="34"/>
        <source>Save as default settings</source>
        <translation>Использовать по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="54"/>
        <source>OK</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="61"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>MultipartDocFormatConfiguratorWidget</name>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="19"/>
        <source>Create annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="25"/>
        <source>Separate sequences</source>
        <translation>Разделить последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="32"/>
        <source>Merge sequences</source>
        <translation>Объединить последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="41"/>
        <source>Gap length:</source>
        <translation>Длина пропуска</translation>
    </message>
</context>
<context>
    <name>ProjectTreeItemSelectorDialogBase</name>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="13"/>
        <source>Select Item</source>
        <translation>Выбор элемента</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="20"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="43"/>
        <source>OK</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="53"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>RemovePartFromSequenceDialog</name>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="14"/>
        <source>Remove subsequence</source>
        <translation>Удаление подпоследовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="22"/>
        <source>Region to remove</source>
        <translation>Удаляемый регион</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="62"/>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="96"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="69"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="78"/>
        <source>Annotations region resolving mode</source>
        <translation>Способ обработки аннотаций</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="86"/>
        <source>Resize</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="111"/>
        <source>Save to new file</source>
        <translation>Сохранить в новый файл</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="123"/>
        <source>Merge annotations to this file</source>
        <translation>Сохранить связанные аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="132"/>
        <source>Document location:</source>
        <translation>Адрес документа:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="142"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="149"/>
        <source>Document format:</source>
        <translation>Формат:</translation>
    </message>
</context>
<context>
    <name>SelectFormatToSaveDialog</name>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="13"/>
        <source>Select format to save sequence</source>
        <translation>Выберите формат для сохранения последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="37"/>
        <source>Create</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="44"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>SeqPasterWidget</name>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="14"/>
        <source>Create annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="26"/>
        <source>Paste data here</source>
        <translation>Вставьте текст:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="43"/>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="53"/>
        <source>Custom settings</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="59"/>
        <source>Alphabet:</source>
        <translation>Алфавит:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="69"/>
        <source>Skip unknown symbols</source>
        <translation>Пропускать неизвестные символы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="79"/>
        <source>Replace unknown symbols with</source>
        <translation>Заменять незивестные символы:</translation>
    </message>
</context>
<context>
    <name>SeqPasterWidgetController</name>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="55"/>
        <source>Input sequence is empty</source>
        <translation type="unfinished">Входная последовательность пуста</translation>
    </message>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="59"/>
        <source>Replace symbol is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="75"/>
        <source>Alphabet not detected</source>
        <translation type="unfinished">Алфавит не определён</translation>
    </message>
</context>
<context>
    <name>U2::AddExistingDocumentDialogImpl</name>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="149"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="155"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="161"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="167"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="173"/>
        <source>Error!</source>
        <translation>Внутренняя ошибка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="65"/>
        <source>Project is locked</source>
        <translation>Проект заблокирован</translation>
    </message>
    <message>
        <source>open_file_dialog_caption</source>
        <translation type="obsolete">Выбор документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="86"/>
        <source>Open file</source>
        <translation>Выбор файла для индексирования</translation>
    </message>
    <message>
        <source>File %1
does not exist!</source>
        <translation type="obsolete">Файл %1 не существует!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="149"/>
        <source>File %1 does not exist!</source>
        <translation>Файл %1 не существует!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="155"/>
        <source>Document URL is empty!</source>
        <translation>Не указан адрес документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="161"/>
        <source>Document is already added!</source>
        <translation>Документ уже добавлен в проект</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="167"/>
        <source>Document format is not selected!</source>
        <translation>Не выбран формат</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="173"/>
        <source>IO adapter not found!</source>
        <translation>Не найден адаптер ввода/вывода</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="184"/>
        <source>Save as</source>
        <translation>Сохранить как</translation>
    </message>
</context>
<context>
    <name>U2::AddNewDocumentDialogImpl</name>
    <message>
        <location filename="../src/util_gui/AddNewDocumentDialogImpl.cpp" line="114"/>
        <source>Save file</source>
        <translation>Создание документа</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Ошибка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddNewDocumentDialogImpl.cpp" line="48"/>
        <source>Project is locked</source>
        <translation>Проект заблокирован</translation>
    </message>
</context>
<context>
    <name>U2::AddToViewTask</name>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="76"/>
        <source>Add object to view %1</source>
        <translation>Добавление объекта в окно: %1</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="91"/>
        <source>Document was removed %1</source>
        <translation>Документ был удалён: %1</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="96"/>
        <source>Object not found %1</source>
        <translation>Объект не найден: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="100"/>
        <source>View was closed %1</source>
        <translation>Окно было закрыто: %1</translation>
    </message>
</context>
<context>
    <name>U2::AnnotationSettingsDialogImpl</name>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="38"/>
        <source>Annotation name</source>
        <translation type="unfinished">Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="39"/>
        <source>A color used to highlight annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="40"/>
        <source>If checked the annotation will be shown on amino strand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="41"/>
        <source>If unchecked the annotation will not be highlighted with color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="42"/>
        <source>A comma-separated list of qualifier names.&lt;br&gt; The value of qualifiers will be shown instead of the annotation names in PanView</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="138"/>
        <source>Visual qualifiers for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="139"/>
        <source>Please enter a comma-separated list of qualifier names.&lt;br&gt; &lt;i&gt;The value of qualifiers (with list priority) will be shown instead of the annotation names in PanView&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::CreateAnnotationDialog</name>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="25"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Ошибка валидации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="48"/>
        <source>Create annotation</source>
        <translation>Создание аннотации</translation>
    </message>
</context>
<context>
    <name>U2::CreateAnnotationWidgetController</name>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="90"/>
        <source>&lt;auto&gt;</source>
        <translation>&lt;авто&gt;</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="136"/>
        <source>Save file</source>
        <translation>Создание документа</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="183"/>
        <source>Select annotation saving parameters</source>
        <translation>Не выбран объект для размещения аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="186"/>
        <source>Document is already added to the project: &apos;%1&apos;</source>
        <translation type="unfinished">Документ уже существует: %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="192"/>
        <source>Illegal folder: %1</source>
        <translation>Не найден путь: %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="198"/>
        <source>Annotation name is empty</source>
        <translation>Не указано имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="203"/>
        <source>Annotation name is too long!
Maximum allowed size: %1 (Genbank format compatibility issue)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotation name is too long</source>
        <translation type="obsolete">Слишком длинное имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="208"/>
        <source>Illegal annotation name</source>
        <translation>Нелегальные символы в имени аннотации. Допустимы только цифры, буквы и подчёркивания</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="213"/>
        <source>Group name is empty</source>
        <translation>Не указано имя группы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="218"/>
        <source>Illegal group name</source>
        <translation>Нелегальные символы в имени группы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="222"/>
        <source>Invalid location! Location must be in GenBank format.
Simple examples:
1..10
join(1..10,15..45)
complement(5..15)</source>
        <translation>Ошибка в задании региона! Регион должен быть задан в формате GenBank.
Простые примеры:
1..10
join(1..10,15..45)
complement(5..15)</translation>
    </message>
    <message>
        <source>Invalid location</source>
        <translation type="obsolete">Неверный регион</translation>
    </message>
</context>
<context>
    <name>U2::CreateDocumentFromTextDialogController</name>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="45"/>
        <source>Select file to save...</source>
        <translation>Сохранение файла</translation>
    </message>
    <message>
        <source>Directory to save is not exists</source>
        <translation type="obsolete">Директория не существует</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="64"/>
        <source>No path specified</source>
        <translation>Путь не задан</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="86"/>
        <source>warning</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="86"/>
        <source>The document already in the project</source>
        <translation>Документ уже открыт в проекте</translation>
    </message>
    <message>
        <source>Entered save filepath is empty</source>
        <translation type="obsolete">Не задан путь</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="77"/>
        <source>Sequence name is empty</source>
        <translation>Имя последовательности пусто</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="59"/>
        <source>Filename is empty</source>
        <translation>Не задано имя файла</translation>
    </message>
</context>
<context>
    <name>U2::CreateObjectRelationDialogController</name>
    <message>
        <source>warning</source>
        <translation type="obsolete">Внимание</translation>
    </message>
    <message>
        <source>annotations_out_of_range</source>
        <translation type="obsolete">Аннотированный регион выходит за пределы последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateObjectRelationDialogController.cpp" line="45"/>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateObjectRelationDialogController.cpp" line="46"/>
        <source>Found annotations that are out of the sequence range, continue?</source>
        <translation>Найдены аннотации, выходящие за границы последовательности. Продолжить?</translation>
    </message>
</context>
<context>
    <name>U2::DownloadRemoteFileDialog</name>
    <message>
        <source>Select file to save</source>
        <translation type="obsolete">Укажите сохраняемый файл</translation>
    </message>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="58"/>
        <source>Select directory to save</source>
        <translation>Папка для сохранения</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Ошибка!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="91"/>
        <source>Resource id is empty!</source>
        <translation>Идентификатор ресурса пуст!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="97"/>
        <source>No directory selected for saving file!</source>
        <translation>Не задана директория для сохранения файла!</translation>
    </message>
    <message>
        <source>Directory doesn&apos;t exists</source>
        <translation type="obsolete">Папка не существует</translation>
    </message>
    <message>
        <source>Directory %1 doesn&apos;t exists
Do you wish to create this directory?</source>
        <translation type="obsolete">Папка %1 не существует
Вы желаете создать эту папку?</translation>
    </message>
    <message>
        <source>Unable to create directory %1!</source>
        <translation type="obsolete">Невозможно создать папку %1!</translation>
    </message>
    <message>
        <source>Directory %1 does not exist!</source>
        <translation type="obsolete">Директория %1 не существует!</translation>
    </message>
</context>
<context>
    <name>U2::EditQualifierDialog</name>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="63"/>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="67"/>
        <source>Error!</source>
        <translation>Проблема</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="63"/>
        <source>Illegal qualifier name</source>
        <translation>Нелегальные символы в имени квалификатора</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="67"/>
        <source>Illegal qualifier value</source>
        <translation>Нелегальные символы в значении квалификатора</translation>
    </message>
</context>
<context>
    <name>U2::EditSequenceDialogController</name>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="26"/>
        <source>Insert sequence</source>
        <translation type="unfinished">Вставить последовательность</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="28"/>
        <source>Replace sequence</source>
        <translation type="unfinished">Заменить последовательность</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="60"/>
        <source>Directory to save is not exists</source>
        <translation type="unfinished">Директория не существует</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="64"/>
        <source>Entered path is empty</source>
        <translation type="unfinished">Не задан путь</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="68"/>
        <source>Filename is empty</source>
        <translation type="unfinished">Не задано имя файла</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="86"/>
        <source>Select file to save...</source>
        <translation type="unfinished">Сохранение файла</translation>
    </message>
</context>
<context>
    <name>U2::GObjectView</name>
    <message>
        <location filename="../src/ObjectViewModel.cpp" line="81"/>
        <source>Object is already added to view %1!</source>
        <translation>Объект уже добавлен в окно &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewModel.cpp" line="95"/>
        <source>Can&apos;t add object: %1</source>
        <translation>Не удалось добавить объект: %1</translation>
    </message>
</context>
<context>
    <name>U2::GUIUtils</name>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="99"/>
        <location filename="../src/util_gui/GUIUtils.cpp" line="109"/>
        <location filename="../src/util_gui/GUIUtils.cpp" line="127"/>
        <source>Error!</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="99"/>
        <source>Document URL is empty!</source>
        <translation type="unfinished">Пустая ссылка</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="109"/>
        <source>Unable to launch default web browser.</source>
        <translation>Не удалось запустить стандартный браузер Интернет</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="127"/>
        <source>Please specify the browser executable</source>
        <translation>Не указано приложение браузера</translation>
    </message>
</context>
<context>
    <name>U2::Header</name>
    <message>
        <location filename="../src/NotificationWidget.cpp" line="26"/>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/NotificationWidget.cpp" line="27"/>
        <source>Always on top</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LoadRemoteDocumentAndOpenViewTask</name>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="213"/>
        <source>Cannot find %1 in %2 database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="176"/>
        <location filename="../src/OpenViewTask.cpp" line="182"/>
        <source>Load remote document and open view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LoadUnloadedDocumentAndOpenViewTask</name>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="43"/>
        <source>Load document: &apos;%1&apos;</source>
        <translation>Загрузка документа: %1</translation>
    </message>
</context>
<context>
    <name>U2::LogViewWidget</name>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="47"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="52"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="56"/>
        <source>Dump performance counters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="59"/>
        <source>Append separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="61"/>
        <source>Clear log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="97"/>
        <source>Copy</source>
        <translation type="unfinished">Копировать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="175"/>
        <source>logview_set_case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="178"/>
        <source>logview_use_regexp</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::MultiPartDocFormatConfigurator</name>
    <message>
        <location filename="../src/util_gui/BaseDocumentFormatConfigurators.cpp" line="53"/>
        <source>%1 format settings</source>
        <translation>Опции формата %1</translation>
    </message>
</context>
<context>
    <name>U2::Notification</name>
    <message>
        <location filename="../src/Notification.cpp" line="123"/>
        <source>Remove notification after closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Notification.cpp" line="138"/>
        <source>Detailed message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ObjectViewTask</name>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="18"/>
        <source>Update &apos;%1&apos; to &apos;%2&apos; state</source>
        <translation>Обновление &quot;%1&quot; в состояние &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="27"/>
        <source>Open new &apos;%1&apos;</source>
        <translation>Открытие нового окна  &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="29"/>
        <source>Open &apos;%1&apos;</source>
        <translation>Открытие окна &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::ObjectViewTreeController</name>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="33"/>
        <source>Activate view</source>
        <translation>Переключиться на окно</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="38"/>
        <source>Add bookmark</source>
        <translation>Добавить закладку</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="42"/>
        <source>Remove bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="48"/>
        <source>Rename bookmark</source>
        <translation>Переименовать закладку</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="325"/>
        <source>New bookmark</source>
        <translation>Закладка</translation>
    </message>
</context>
<context>
    <name>U2::ProjectFileUtils</name>
    <message>
        <source>error_open_file %1</source>
        <translation type="obsolete">Ошибка открытия файла &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="211"/>
        <source>Project version is not a double value</source>
        <translation>Версия проекта не является вещественным значением</translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="216"/>
        <source>Project file was created by a newer version of UGENE. Please update UGENE.</source>
        <translation>Файл проекта был создан более ранней версией UGENE. Пожалуйста, обновите UGENE.</translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="222"/>
        <source>Not a valid UGENE project file %1</source>
        <translation>Некорректный файл проекта UGENE: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>U2::ProjectParser10</name>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="293"/>
        <source>Can&apos;t find project file: %1, ignoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="297"/>
        <source>Duplicate document found: %1, ignoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="337"/>
        <source>The last loaded state was locked by format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ProjectTreeController</name>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="64"/>
        <source>Remove selected documents</source>
        <translation>Удалить выбранные документы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="70"/>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="510"/>
        <source>Load selected documents</source>
        <translation>Загрузить выбранные документы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="461"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="467"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1080"/>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1153"/>
        <source>[loading %1%]</source>
        <translation>[прочитано %1%]</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="458"/>
        <source>Existing document</source>
        <translation>Существующий документ</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="82"/>
        <source>Unload selected document</source>
        <translation>Выгрузить выбранные документы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1096"/>
        <source>Locks:</source>
        <translation>Блокировки:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1099"/>
        <source>Project is locked</source>
        <translation>Проект заблокирован</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="85"/>
        <source>Group by document</source>
        <translation>Группировать по файлам</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="91"/>
        <source>Group by type</source>
        <translation>Группировать по типам</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="97"/>
        <source>No groups</source>
        <translation>Не группировать</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="203"/>
        <source>Unloaded object refers to unloaded type: %1</source>
        <translation>Выгруженный объект %1 ссылается на неизвестный тип</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="511"/>
        <source>Unload selected documents</source>
        <translation>Выгрузить выбранные документы</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="513"/>
        <source>Load selected objects</source>
        <translation>Загрузить выбранные объекты</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="514"/>
        <source>Unload selected objects</source>
        <translation>Выгрузить выбранные объекты</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="76"/>
        <source>Lock document for editing</source>
        <translation>Заблокировать внесение изменений</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="79"/>
        <source>Unlock document for editing</source>
        <translation>Снять блокировку изменений</translation>
    </message>
</context>
<context>
    <name>U2::RemovePartFromSequenceDialogController</name>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="49"/>
        <source>There must be only one region to delete</source>
        <translation>Допускается только один регион</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="53"/>
        <source>Unable to parse region to delete</source>
        <translation>Некорректный регион</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="59"/>
        <source>Cannot remove the whole sequence</source>
        <translation>Невозможно уделить всю последовательность</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="64"/>
        <source>Region to delete is out of sequence bounds</source>
        <translation>Регион выходит за границы последовательности</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="75"/>
        <source>Select file to save...</source>
        <translation>Сохранение файла</translation>
    </message>
</context>
<context>
    <name>U2::SaveDocumentGroupController</name>
    <message>
        <location filename="../src/util_gui/SaveDocumentGroupController.cpp" line="18"/>
        <source>Select file location</source>
        <translation>Укажите местонахождение файла</translation>
    </message>
</context>
<context>
    <name>U2::UnloadDocumentTask</name>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="26"/>
        <source>Unload document task: %1</source>
        <translation>Выгрузка документа: %1</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="40"/>
        <source>Document &apos;%1&apos; can&apos;t be unloaded: </source>
        <translation>Документ &quot;%1&quot; не может быть выгружен</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="43"/>
        <source>save failed!</source>
        <translation>Сохранение провалилось</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="54"/>
        <source>unexpected error</source>
        <translation>неизвестная ошибка</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="82"/>
        <source>Question?</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="82"/>
        <source>Save document: %1</source>
        <translation>%1 был изменён, сохранить документ? </translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="101"/>
        <source>Failed to unload document</source>
        <translation>Не удалось выгрузить документ</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="105"/>
        <source>Failed to unload document: %1, error: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="114"/>
        <source>There is an active view with document content</source>
        <translation>Документ используется в открытых окнах</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="119"/>
        <source>Document is locked by some algorithm and cannot be unloaded</source>
        <translation>Документ был заблокирован одним из алгоритмов и не может быть выгружен</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="107"/>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
</context>
</TS>
